@@ -1,18 +1,43 @@
 aggregated.index.number<-function(x,base,type,name,opt.plot=FALSE,opt.summary=FALSE){
 
+x<-as.matrix(x)
+opt<-TRUE
 
-if (is.matrix(x)==FALSE){
+
+if (is.matrix(x)==FALSE|!dim(x)[2]>=2|is.numeric(as.matrix(x))==FALSE){
+opt<-FALSE
 message("Please, introduce a matrix with the prices of different products","\n")
 }
 if (is.character(base)==FALSE){
-    message("Please, introduce the type of index number","\n")
+  opt<-FALSE
+  message("Please, introduce the type of index number","\n")
 }
 if (is.character(type)==FALSE){
+  opt<-FALSE
   message("Please, introduce the type of aggregate index number","\n")
 }
-if (is.character(name)==FALSE){
-message("Please, introduce a name of the variable as a character","\n")
+if (base=="serie"){
+if (sum(type!=c("arithmetic","geometric","harmonic","BDutot"))==4){
+  opt<-FALSE
+  message("Please, introduce an adequate type of aggregate index number","\n")
 }
+}
+if (base=="chain"){
+  if (sum(type!=c("Carli","Jevons","Dutot"))==3){
+    opt<-FALSE
+    message("Please, introduce an adequate type of aggregate index number","\n")
+  }
+}
+if (is.character(name)==FALSE){
+  opt<-FALSE
+  message("Please, introduce a name of the variable as a character","\n")
+}
+if (is.logical(opt.plot)==FALSE|is.logical(opt.summary)==FALSE){
+    opt<-FALSE
+    message("Please, revise the logical options opt.plot and opt.summary","\n")
+}
+
+if (opt==TRUE){
 n.prod<-ncol(x)
 ind.index<-matrix(0,ncol=ncol(x),nrow=nrow(x))
 if (base=="serie"){
@@ -26,6 +51,7 @@ ind.index[,i]<-index.number.chain(x[,i],name,opt.plot=FALSE,opt.summary=FALSE)[,
 }
 }
 
+if (base=="serie"){
 if (type=="arithmetic"){index.n.aggregate<-apply(ind.index,1,mean)}
 if (type=="geometric"){index.n.aggregate<-apply(ind.index,1,prod)^(1/n.prod)}
 if (type=="harmonic"){index.n.aggregate<-n.prod/apply(1/ind.index,1,sum)}
@@ -33,7 +59,23 @@ if (type=="BDutot"){
   ind.index<-apply(x,1,sum)
   index.n.aggregate<-index.number.serie(ind.index,name,opt.plot = FALSE, opt.summary = FALSE)[,3]
 }
-
+if (sum(type!=c("arithmetic","geometric","harmonic","BDutot"))==4){
+  opt.plot=FALSE
+  message("Please, introduce an adequate type of aggregate index number","\n")
+}
+}
+if (base=="chain"){
+  if (type=="Carli"){index.n.aggregate<-apply(ind.index,1,mean)}
+  if (type=="Jevons"){index.n.aggregate<-apply(ind.index,1,prod)^(1/n.prod)}
+  if (type=="Dutot"){
+    ind.index<-apply(x,1,sum)
+    index.n.aggregate<-index.number.serie(ind.index,name,opt.plot = FALSE, opt.summary = FALSE)[,3]
+  }
+  if (sum(type!=c("Carli","Jevons","Dutot"))==3){
+    opt.plot=FALSE
+    message("Please, introduce an adequate type of aggregate index number","\n")
+  }
+}
 
 if (opt.plot==TRUE){
 if (is.character(name)){
@@ -63,6 +105,10 @@ if (type=="arithmetic"){message("Arithmetic","\n")}
 if (type=="geometric"){message("Geometric","\n")}
 if (type=="harmonic"){message("Harmonic","\n")}
 if (type=="BDutot"){message("Bradstreet-Dutot","\n")}
+if (type=="Carli"){message("Carli","\n")}
+if (type=="Jevons"){message("Jevons","\n")}
+if (type=="Dutot"){message("Dutot","\n")}
+
 
 
 message(" ","\n")
@@ -77,3 +123,4 @@ names(results)<-c("Summary","Agg. index number")
 }
 return(results)
 }
+}
